This change should be noted in the CHANGES file also, just in case
folks are actually using this key currently.
Erik
On Nov 29, 2004, at 5:38 PM, [EMAIL PROTECTED] wrote:
bmesser 2004/11/29 14:38:48
Modified: src/java/org/apache/lucene/store FSDirectory.java
Log:
change lockdir to lockDir so that it follows the existing casing
pattern.
Revision Changes Path
1.39 +2 -2
jakarta-lucene/src/java/org/apache/lucene/store/FSDirectory.java
Index: FSDirectory.java
===================================================================
RCS file:
/home/cvs/jakarta-lucene/src/java/org/apache/lucene/store/
FSDirectory.java,v
retrieving revision 1.38
retrieving revision 1.39
diff -u -r1.38 -r1.39
--- FSDirectory.java 18 Nov 2004 18:37:53 -0000 1.38
+++ FSDirectory.java 29 Nov 2004 22:38:48 -0000 1.39
@@ -49,11 +49,11 @@
Boolean.getBoolean("disableLuceneLocks") ||
Constants.JAVA_1_1;
/**
* Directory specified by <code>org.apache.lucene.lockdir</code>
* or <code>java.io.tmpdir</code> system property
*/
public static final String LOCK_DIR =
- System.getProperty("org.apache.lucene.lockdir",
+ System.getProperty("org.apache.lucene.lockDir",
System.getProperty("java.io.tmpdir"));
/** The default class which implements filesystem-based
directories. */
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
@@ -49,11 +49,11 @@
Constants.JAVA_1_1;
/**
- * Directory specified by <code>org.apache.lucene.lockdir</code>
+ * Directory specified by <code>org.apache.lucene.lockDir</code>
* or <code>java.io.tmpdir</code> system property
*/